@@ -46,7 +46,7 @@ try:
         wd = shdata['RT/Watchdog']['D1']        
         if today!=lastdate:            
             wd[today] = wd[lastdate].copy()
-            wd.tags[today].Write()
+            # wd.tags[today].Write()
             lastdate=today
 
         dfwatchdog = wd[today]
